@@ -1,5 +1,5 @@
 /*
- * $Id: brokerUpc.c,v 1.31 2009/11/09 21:49:11 buccella Exp $
+ * $Id: brokerUpc.c 62474f7 on Fri Oct 18 15:42:56 2013 -0400 by buccella $
  *
  * © Copyright IBM Corp. 2005, 2007
  *
@@ -66,11 +66,19 @@ void            closeProviderContext(BinRequestContext * ctx);
 
 static CMPI_MUTEX_TYPE mtx = NULL;
 
+void
+freeUpCallMtx()
+{
+  free(mtx);
+}
+
 void
 lockUpCall(const CMPIBroker * mb)
 {
-  if (mtx == NULL)
+  if (mtx == NULL) {
     mtx = mb->xft->newMutex(0);
+    atexit(freeUpCallMtx);
+  }
   mb->xft->lockMutex(mtx);
 }
 
