@@ -1,6 +1,6 @@
 
 /*
- * $Id: cimXmlParser.c c29c15e on Wed Feb 19 18:47:31 2014 -0500 by Dave Heller $
+ * $Id: cimXmlParser.c a9dda19 on Fri Apr 25 19:12:04 2014 -0400 by Dave Heller $
  *
  *  © Copyright IBM Corp. 2005, 2007
  *
@@ -1724,7 +1724,7 @@ scanCimXmlRequest(CimRequestContext *ctx, char *xmlData, int *rc)
   control.reqHdr.binCtx = calloc(1, sizeof(BinRequestContext));
   control.reqHdr.principal = ctx->principal;
   control.reqHdr.sessionId = ctx->sessionId;
-  control.reqHdr.role = NULL;
+  control.reqHdr.role = ctx->role;
   control.paramValues.last = control.paramValues.first = NULL;
   control.properties.last = control.properties.first = NULL;
   control.qualifiers.last = control.qualifiers.first = NULL;
