@@ -1,6 +1,6 @@
 
 /*
- * $Id: cimcClientSfcbLocal.c,v 1.32 2009/09/01 18:59:06 buccella Exp $
+ * $Id: cimcClientSfcbLocal.c 745f4b0 on Fri Oct 18 16:15:59 2013 -0400 by buccella $
  *
  * © Copyright IBM Corp. 2006, 2007
  *
@@ -168,6 +168,7 @@ cloneClient(Client __attribute__ ((unused)) *cl, CMPIStatus *st)
   return NULL;
 }
 
+/* releases the Client created in CMPIConnect2() */
 static CMPIStatus
 releaseClient(Client * mb)
 {
@@ -2089,6 +2090,23 @@ void _Cleanup_SfcbLocal_Env(void)
     _SFCB_TRACE_STOP();
 }
 
+void *
+newIndicationListener(ClientEnv *ce, int sslMode, int *portNumber, char **socketName,
+                     void (*fp) (CMPIInstance *indInstance), CMPIStatus* rc)
+{
+  fprintf(stderr, "*** newIndicationListener not supported for SfcbLocal\n");
+  return NULL;
+}
+
+void * _markHeap() {
+  return markHeap();
+}
+
+void _releaseHeap(void* heap) {
+  releaseHeap(heap);
+  return;
+}
+
 /* called by SFCC's NewCIMCEnv() */
 ClientEnv      *
 _Create_SfcbLocal_Env(char __attribute__ ((unused)) *id, unsigned int options, 
@@ -2108,6 +2126,9 @@ _Create_SfcbLocal_Env(char __attribute__ ((unused)) *id, unsigned int options,
     newDateTime,
     newDateTimeFromBinary,
     newDateTimeFromChars,
+    newIndicationListener,
+    _markHeap,
+    _releaseHeap
   };
 
   // localClientMode=1;
